##  AI-Assisted Text
The AI-assisted text allows you to effortlessly create or enhance various types of text content by analyzing the context and providing options to improve it through rewriting or summarizing existing text.
For example, currently, AI-assisted text analyzes the content and context of the fact sheet to generate a concise and accurate description for fact sheets. This feature streamlines the process of creating informative descriptions, saving users time and effort.
To use the AI-assisted text feature, click on the AI help icon located at the bottom right corner of the description field. It automatically generates a description, which you can then refine, rewrite, summarize, or format as needed. Additionally, you can explain the relations of all related fact sheets, create bullet points, format them as paragraphs, or undo changes.
![AI-assisted Text in Description of a Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274cef657a441014a9bfe47cb1c361b7_LowRes.png)
AI-Assisted Text in Description of a Fact Sheet
